import Xmobar
import Config
import Monitors

topProcL p = TopProc (p <~> args) 15
  where template = "<both1>  <both2>  <both3> ·  <mboth1>  <mboth2>  <mboth3>"
        args = ["-t", template, "-w", "12", "-L" , "10", "-H", "80"]

diskIOS p = DiskIO [("/", "<read> <write>")] (diskArgs p) 10

cpuFreq' p = CpuFreq (p <~> args) 50
  where args = ["-t" , "<avg>" , "-L", "1", "-H", "2", "-S", "Off" , "-d", "2"]

memory' = Memory args 20
  where template = "<used> <available>"
        args = ["-t", template , "-p", "2", "-d", "1", "--", "--scale", "1024"]

master p = Volume "default" "Master" (args ++ ("--":ext)) 10
  where args = ["-t", "<status> <volume>"]
        ext = ["-C", pForeground p, "-c", "sienna4", "-O", "🎼", "-o", "🔇"]

capture = Volume "default" "Capture" ["-t", "<volume>"] 10

batt0 p =
  BatteryN ["BAT0"]
           ["-t", "<acstatus>"
           , "-S", "Off", "-d", "0", "-m", "3"
           , "-L", "10", "-H", "90", "-p", "3"
           , "--low", pHigh p, "--normal", pNormal p, "--high", pLow p
           , "--"
           , "-P"
           , "-a", "notify-send -u critical 'Battery running out!!!!!!'"
           , "-A", "7"
           , "-i", "\9211"
           , "-O", "\129707 <left> <timeleft> <watts>"
           , "-o", "🔋" ++ " <left> <timeleft> <watts>"
           , "-H", "10", "-L", "7"
           , "-h", pHigh p, "-l", pLow p] 50 "batt0"

weath st p =
  WeatherX st
           [ ("", "🌡")
           , ("clear", "🔆")
           , ("sunny", "🔆")
           , ("fair", "🔆")
           , ("mostly clear", "🌤")
           , ("mostly sunny", "🌤")
           , ("partly sunny", "⛅")
           , ("obscured", "🌁") -- 🌫
           , ("fog", "🌁") -- 🌫
           , ("foggy", "🌁") -- 🌫
           , ("cloudy", "☁️")
           , ("overcast", "☁️")
           , ("partly cloudy", "⛅")
           , ("mostly cloudy", "☁️")
           , ("considerable cloudiness", "⛈")
           , ("light rain", "🌧")
           , ("rain", "⛆")
           , ("ice crystals", "❄")
           , ("light snow", "🌨")
           , ("snow", "❄")
           ]
           (mkArgs p ["-t", "<skyConditionS> <tempC>° <weather> 🌫 <windKmh>"
                     , "-L", "10", "-H", "25" , "-T", "25", "-E", ".."]
                     ["-w", ""])
           18000

config p = (baseConfig p) {
  position = TopSize C 100 (defaultHeight - 2)
  , textOutput = True
  , textOutputFormat = Ansi
  , font = "xft:DejaVu Sans Mono-8"
  , commands = [ Run (topProcL p)
               , Run (batt0 p)
               , Run (cpu p)
               , Run (cpuFreq' p)
               , Run memory'
               , Run (diskU p)
               , Run (diskIOS p)
               , Run (kbd p)
               , Run (coreTemp p)
               , Run (wireless p "wlp164s0")
               , Run (dynNetwork p)
               , Run (vpnMark "wg-mullvad")
               , Run tun0
               , Run (master p)
               , Run capture
               , Run laTime
               , Run localTime
               , Run (weath "EGPH" p)
               ]
  , template = "|batt0| "
             ++ " |wg-mullvad||tun0||wlp164s0wi|"
             ++ " |dynnetwork| "
             ++ "  |default:Master| 🗪 |default:Capture|"
             ++ "  |EGPH|"
             ++ "{*}"
             ++ "|kbd|"
             ++ " |cpufreq|"
             ++ " |multicpu|"
             ++ " |multicoretemp|"
             ++ "   |top| "
             ++  " ␞ |memory| "
             ++ " |diskio| 🖴 |disku| " -- 📀 🖴 🖫
             ++ "  |datetime| "
             ++ "|laTime| "
  }

main :: IO ()
main = palette >>= configFromArgs . config >>= xmobar
